/* 
Copyright 2021 Magnus Wirsig

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

/*
SimpleFEC: simple forward error correction with small footprint
This file contains an example program to demonstrate usage and functionality, tested on Ubuntu desktop PC and Atmega 328p microcontroller
*/


#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <inttypes.h>
#include <string.h>
#include "SimpleFec.h"

#ifdef AVR
#include "uart.h"
#endif

int main(/*int argc, char *argv[]*/)
{
#ifdef AVR
    uart_init();
#endif

    printf("Test program\r\n");
    srand(time(NULL));

    char specimen[] = "This is my teststring! 1234567890 I like rainbows. Pigs can't fly! Nothing more to say...";
    int len = strlen(specimen);
    uint8_t fecData[20];

    printf("1 Text: >%s<\r\n", specimen);

    SimpleFecPutFec(specimen, len, fecData);

    for(int i = 0; i<len; i+=4)
	specimen[i] ^= (1<<rand()%8);

    printf("2 Text: >%s<\r\n", specimen);

    SimpleFecRepairData(specimen, len, fecData);

    printf("3 Text: >%s<\r\n", specimen);

    printf("END\r\n");

#ifdef AVR
    for(;;)
    ;
#endif

    return 0;
}
